# Copyright (C) 2010 by Intevation GmbH
# Authors:
# Ingo Weinzierl <ingo.weinzierl@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

"""Certificate validation failure processing"""

import inteproxy.main
from inteproxy.resources import gettext as _


# keep track of the URLs for which the dialog was already shown.
dialog_shown_for = dict()

def handle_certificate_validation_error(remote_url):
    """This function might be called if an error occured while validating
    certificates.

    After calling this function, a dialog is opened to inform the user about the
    validation failure. title and content of this dialog are currently static
    string. The dialog gives users the choice to accept or reject the
    connection to the remote server. remote_url is used to cache the choice for
    the time InteProxy is running to avoid showing the dialog twice for the same
    connection."""
    title   = _("InteProxy: This connection is untrusted.")
    content = _("The certificate validation failed.")

    if remote_url in dialog_shown_for:
        return dialog_shown_for[remote_url]

    accepted = inteproxy.main.the_application.run_certificate_dialog(title,
                                                                     content)
    dialog_shown_for[remote_url] = accepted
    return accepted

