# Copyright (C) 2012 by Intevation GmbH
# Authors:
# Bernhard Herzog <bh@intevation.de>
# Andre Heinecke <aheinecke@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details.

""" On the fly decompression of a data stream """

class DecompressStream(object):
    """A class to wrap around a data stream that contains compressed data.

    The decompression object can be given on initalization.
    """

    def __init__(self, infile, decompressobj):
        """Initialize the DecompressStream Object

        The parameter infile is used as input stream
        and the parameter decompressobj to provide the decompression.
        """
        self.infile = infile
        self.decompressor = decompressobj

    def read(self, amount = -1):
        """Decompressed the stream and returns the uncompressed data.

        A negative parameter for amount indicates that the complete
        stream should be decompressed.
        """
        decompressed_chunks = []
        count = 0

        if amount < 0:
            compressed = self.decompressor.unconsumed_tail
            compressed += self.infile.read()
            return self.decompressor.decompress(compressed)

        while count < amount:
            max_read = amount - count
            compressed = self.decompressor.unconsumed_tail
            if not compressed:
                compressed = self.infile.read(amount)
                if not compressed:
                    break
            deflated = self.decompressor.decompress(compressed, max_read)
            count += len(deflated)
            decompressed_chunks.append(deflated)

        return "".join(decompressed_chunks)
