# Copyright (C) 2012 by Intevation GmbH
# Authors:
# Sascha L. Teichmann <sascha.teichmann@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with the software for details

"""Tests for the inteproxy.chunkedwriter module"""

import unittest
import StringIO

from random import Random

from inteproxy.chunkedwriter import ChunkedTransferEncodingWriter

class ChunkedTransferEncodingWriterTest(unittest.TestCase):

    def test_chunked_transfer_encoding_writer(self):
        """Test for the ChunkedTransferEncodingWriter"""

        SEED  = 339394899170L
        CHUNK = 4096
        SMALL = 100

        raw = [chr(c)*CHUNK for c in range(ord('A'), ord('Z')+1)]
        source = ''.join(raw)

        output = StringIO.StringIO()
        write = output.write

        writer = ChunkedTransferEncodingWriter(write, CHUNK)

        r = Random(SEED)
        randint, rand = r.randint, r.random
        rest = len(source)
        while rest:
            if rand() < 0.7:
                to_write = randint(1, SMALL)
            else:
                to_write = randint(CHUNK-SMALL, CHUNK+SMALL)
            to_write = min(rest, to_write)
            p = len(source)-rest
            writer.append(source[p:p+to_write])
            rest -= to_write

        writer.finish()
        result = output.getvalue()
        expected = '%x\r\n%s\r\n0\r\n\r\n' % (CHUNK, (
                                              '\r\n%x\r\n' % CHUNK).join(raw))
        self.assertEqual(result, expected)
